<%@ taglib prefix="props" tagdir="/WEB-INF/tags/props" %>
<%@ taglib prefix="l" tagdir="/WEB-INF/tags/layout" %>
<%@ taglib prefix="bs" tagdir="/WEB-INF/tags" %>
<%@ taglib prefix="forms" tagdir="/WEB-INF/tags/forms" %>
<%@ taglib prefix="c" uri="http://java.sun.com/jsp/jstl/core" %>
<%@ taglib prefix="intprop" uri="/WEB-INF/functions/intprop" %>
<%@ taglib prefix="fn" uri="http://java.sun.com/jsp/jstl/functions" %>

<jsp:useBean id="dockerInfoCollector" type="org.jetbrains.teamcity.docker.DockerInfoCollector" scope="request"/>
<style type="text/css">
  .dockerInfo {
    width: 90%;
  }

  .dockerInfo tr td:first-child {
    width: 30%;
  }
</style>
<div class="dockerBuildInfo">

  <c:choose>
    <c:when test="${empty dockerInfoCollector.events}">
      <h3>No docker events have been registered ${build.finished ? "" : "yet"}</h3>
    </c:when>
    <c:otherwise>
      <c:if test="${not empty dockerInfoCollector.pushes}">
        <h3>Images pushed to the registry</h3>
        <table class="dockerInfo">
          <tr>
            <td>REPOSITORY</td>
            <td>TAG</td>
            <td>IMAGE ID</td>
            <td>CREATED</td>
            <td>SIZE</td>
            <td>WILL BE CLEANED</td>
          </tr>
          <c:forEach items="${dockerInfoCollector.pushes}" var="image">
            <tr>
              <td>${image.repo}<c:if test="${not empty image.repo && not empty image.name}">/</c:if>${image.name}</td>
              <td>${image.tag}</td>
              <td>${fn:substring(image.digest,fn:length('sha256:'),fn:length('sha256:')+12)}</td>
              <td><bs:date value="${image.timestamp}" smart="true"/></td>
              <td><bs:fileSize value="${image.size}"/></td>
              <td>${willBeCleaned}</td>
            </tr>
          </c:forEach>
        </table>
      </c:if>
      <br/>
      <a href="javascript:showEventsLog();" id="eventsLogLink">Show docker events log</a>
      <div id="eventsLog" style="display: none;">
        <h3>Docker events log</h3>
        <c:set var="scope" value=""/>
        <c:forEach items="${dockerInfoCollector.events}" var="event">
          <c:set var="info" value="${event.info}"/>

          <c:set var="timepattern" value="HH:mm:ss"/>

          <c:if test="${scope != info.contextLine}">
            <h4><bs:out value="${info.contextLine}"/></h4>
            <c:set var="scope" value="${info.contextLine}"/>
            <c:set var="timepattern" value="dd MMM yy HH:mm:ss"/>
          </c:if>
          <div class="eventLine">

            <span class="timestamp"><bs:date value="${info.timestamp}" pattern="${timepattern}"/></span>
            <span class="infoLine">
                <c:choose>
                  <c:when test="${event.eventName == 'container'}">
                    Container <bs:trim maxlength="12">${info.id}</bs:trim> ${info.stage}
                    <c:if test="${not empty info.from and info.stage == 'CREATE'}">
                      ; from: ${info.from}
                    </c:if>
                  </c:when>
                  <c:when test="${event.eventName == 'push' || event.eventName == 'pull'}">
                    Image ${event.eventName}: ${info}
                  </c:when>
                  <c:otherwise>
                    Unknown event: ${event.eventName}
                  </c:otherwise>
                </c:choose>
            </span>

          </div>
        </c:forEach>
      </div>
    </c:otherwise>
  </c:choose>


</div>

<script>
  function showEventsLog() {
    $j('#eventsLog').css('display', 'block');
    $j('#eventsLogLink').css('display', 'none');
  }

  <c:if test="${empty dockerInfoCollector.pushes}">
    showEventsLog();
  </c:if>

</script>